@@ -2,6 +2,7 @@ __all__ = ['ResultException', 'ResultType', 'Result', 'Ok', 'Err', 'wrap_result'
 
 import types
 import asyncio
+import inspect
 from functools import wraps
 from typing import Any, Callable
 from inspect import iscoroutinefunction
@@ -246,7 +247,7 @@ def auto_unwrap(obj) -> Any:
     """
     This function auto unwraps Ok or Err type of Result
     """
-    if isinstance(obj, type):
+    if inspect.isclass(obj):
         type_ = obj
         new_type_dict = {}
 
